@@ -6,6 +6,7 @@
 #include "ui_configdialog.h"
 #include <QClipboard>
 #include <QDir>
+#include <QFileDialog>
 #include <QMessageBox>
 #ifdef Q_OS_WIN
 #include <windows.h>
@@ -19,6 +20,49 @@ ConfigDialog::ConfigDialog(MainWindow *parent)
     : QDialog(parent), ui(new Ui::ConfigDialog) {
   mainWindow = parent;
   ui->setupUi(this);
+
+  ui->passPath->setText(QtPassSettings::getPassExecutable());
+  setGitPath(QtPassSettings::getGitExecutable());
+  ui->gpgPath->setText(QtPassSettings::getGpgExecutable());
+  ui->storePath->setText(QtPassSettings::getPassStore());
+
+  ui->spinBoxAutoclearSeconds->setValue(QtPassSettings::getAutoclearSeconds());
+  ui->spinBoxAutoclearPanelSeconds->setValue(
+      QtPassSettings::getAutoclearPanelSeconds());
+  ui->checkBoxHidePassword->setChecked(QtPassSettings::isHidePassword());
+  ui->checkBoxHideContent->setChecked(QtPassSettings::isHideContent());
+  ui->checkBoxAddGPGId->setChecked(QtPassSettings::isAddGPGId(true));
+  ui->checkBoxHideOnClose->setChecked(QtPassSettings::isHideOnClose());
+  ui->checkBoxStartMinimized->setChecked(QtPassSettings::isStartMinimized());
+  ui->checkBoxAvoidCapitals->setChecked(QtPassSettings::isAvoidCapitals());
+  ui->checkBoxAvoidNumbers->setChecked(QtPassSettings::isAvoidNumbers());
+  ui->checkBoxLessRandom->setChecked(QtPassSettings::isLessRandom());
+  ui->checkBoxUseSymbols->setChecked(QtPassSettings::isUseSymbols());
+  ui->plainTextEditTemplate->setPlainText(QtPassSettings::getPassTemplate());
+  ui->checkBoxTemplateAllFields->setChecked(
+      QtPassSettings::isTemplateAllFields());
+  ui->checkBoxAutoPull->setChecked(QtPassSettings::isAutoPull());
+  ui->checkBoxAutoPush->setChecked(QtPassSettings::isAutoPush());
+  ui->checkBoxAlwaysOnTop->setChecked(QtPassSettings::isAlwaysOnTop());
+
+  #if defined(Q_OS_WIN ) || defined(__APPLE__)
+    ui->checkBoxUseOtp->hide();
+    ui->label_10->hide();
+  #endif
+
+  setProfiles(QtPassSettings::getProfiles(), QtPassSettings::getProfile());
+  setPwgenPath(QtPassSettings::getPwgenExecutable());
+  setPasswordConfiguration(QtPassSettings::getPasswordConfiguration());
+
+  usePass(QtPassSettings::isUsePass());
+  useAutoclear(QtPassSettings::isUseAutoclear());
+  useAutoclearPanel(QtPassSettings::isUseAutoclearPanel());
+  useTrayIcon(QtPassSettings::isUseTrayIcon());
+  useGit(QtPassSettings::isUseGit());
+  useOtp(QtPassSettings::isUseOtp());
+  usePwgen(QtPassSettings::isUsePwgen());
+  useTemplate(QtPassSettings::isUseTemplate());
+
   ui->profileTable->verticalHeader()->hide();
   ui->profileTable->horizontalHeader()->setStretchLastSection(true);
   ui->label->setText(ui->label->text() + VERSION);
@@ -27,13 +71,20 @@ ConfigDialog::ConfigDialog(MainWindow *parent)
   ui->comboBoxClipboard->addItem(tr("No Clipboard"));
   ui->comboBoxClipboard->addItem(tr("Always copy to clipboard"));
   ui->comboBoxClipboard->addItem(tr("On-demand copy to clipboard"));
-  ui->comboBoxClipboard->setCurrentIndex(0);
+
+  int currentIndex = QtPassSettings::getClipBoardTypeRaw();
+  ui->comboBoxClipboard->setCurrentIndex(currentIndex);
+  on_comboBoxClipboard_activated(currentIndex);
 
   QClipboard *clip = QApplication::clipboard();
   if (!clip->supportsSelection()) {
     useSelection(false);
     ui->checkBoxSelection->setVisible(false);
+  } else {
+    useSelection(QtPassSettings::isUseSelection());
   }
+
+  connect(this, &ConfigDialog::accepted, this, &ConfigDialog::on_accepted);
 }
 
 /**
@@ -46,12 +97,6 @@ ConfigDialog::~ConfigDialog() {
   QtPassSettings::setPassExecutable(ui->passPath->text());
 }
 
-/**
- * @brief ConfigDialog::setPassPath set the pass executable path.
- * @param path
- */
-void ConfigDialog::setPassPath(QString path) { ui->passPath->setText(path); }
-
 /**
  * @brief ConfigDialog::setGitPath set the git executable path.
  * Make sure the checkBoxUseGit is updated.
@@ -59,73 +104,64 @@ void ConfigDialog::setPassPath(QString path) { ui->passPath->setText(path); }
  */
 void ConfigDialog::setGitPath(QString path) {
   ui->gitPath->setText(path);
+  ui->checkBoxUseGit->setEnabled(!path.isEmpty());
   if (path.isEmpty()) {
     useGit(false);
-    ui->checkBoxUseGit->setEnabled(false);
-  } else {
-    ui->checkBoxUseGit->setEnabled(true);
   }
 }
 
-/**
- * @brief ConfigDialog::setGpgPath set the gpg executable path.
- * @param path
- */
-void ConfigDialog::setGpgPath(QString path) { ui->gpgPath->setText(path); }
-
-/**
- * @brief ConfigDialog::setStorePath set the .password-store folder path.
- * @param path
- */
-void ConfigDialog::setStorePath(QString path) { ui->storePath->setText(path); }
-
-/**
- * @brief ConfigDialog::getPassPath return path to pass.
- * @return
- */
-QString ConfigDialog::getPassPath() { return ui->passPath->text(); }
-
-/**
- * @brief ConfigDialog::getGitPath return path to git.
- * @return
- */
-QString ConfigDialog::getGitPath() { return ui->gitPath->text(); }
-
-/**
- * @brief ConfigDialog::getGpgPath return path to gpg.
- * @return
- */
-QString ConfigDialog::getGpgPath() { return ui->gpgPath->text(); }
-
-/**
- * @brief ConfigDialog::getStorePath return path to .password-store.
- * @return
- */
-QString ConfigDialog::getStorePath() { return ui->storePath->text(); }
-
-/**
- * @brief ConfigDialog::usePass return wether or not we want to use pass (or
- * native gpg+git etc).
- * @return
- */
-bool ConfigDialog::usePass() { return ui->radioButtonPass->isChecked(); }
-
 /**
  * @brief ConfigDialog::usePass set wether or not we want to use pass.
  * Update radio buttons accordingly.
  * @param usePass
  */
 void ConfigDialog::usePass(bool usePass) {
-  if (usePass) {
-    ui->radioButtonNative->setChecked(false);
-    ui->radioButtonPass->setChecked(true);
-  } else {
-    ui->radioButtonNative->setChecked(true);
-    ui->radioButtonPass->setChecked(false);
-  }
+  ui->radioButtonNative->setChecked(!usePass);
+  ui->radioButtonPass->setChecked(usePass);
   setGroupBoxState();
 }
 
+void ConfigDialog::on_accepted() {
+  QtPassSettings::setPassExecutable(ui->passPath->text());
+  QtPassSettings::setGitExecutable(ui->gitPath->text());
+  QtPassSettings::setGpgExecutable(ui->gpgPath->text());
+  QtPassSettings::setPassStore(
+      Util::normalizeFolderPath(ui->storePath->text()));
+  QtPassSettings::setUsePass(ui->radioButtonPass->isChecked());
+  QtPassSettings::setClipBoardType(ui->comboBoxClipboard->currentIndex());
+  QtPassSettings::setUseSelection(ui->checkBoxSelection->isChecked());
+  QtPassSettings::setUseAutoclear(ui->checkBoxAutoclear->isChecked());
+  QtPassSettings::setAutoclearSeconds(ui->spinBoxAutoclearSeconds->value());
+  QtPassSettings::setUseAutoclearPanel(ui->checkBoxAutoclearPanel->isChecked());
+  QtPassSettings::setAutoclearPanelSeconds(
+      ui->spinBoxAutoclearPanelSeconds->value());
+  QtPassSettings::setHidePassword(ui->checkBoxHidePassword->isChecked());
+  QtPassSettings::setHideContent(ui->checkBoxHideContent->isChecked());
+  QtPassSettings::setAddGPGId(ui->checkBoxAddGPGId->isChecked());
+  QtPassSettings::setUseTrayIcon(ui->checkBoxUseTrayIcon->isChecked());
+  QtPassSettings::setHideOnClose(hideOnClose());
+  QtPassSettings::setStartMinimized(ui->checkBoxStartMinimized->isChecked());
+  QtPassSettings::setProfiles(getProfiles());
+  QtPassSettings::setUseGit(ui->checkBoxUseGit->isChecked());
+  QtPassSettings::setUseOtp(ui->checkBoxUseOtp->isChecked());
+  QtPassSettings::setPwgenExecutable(ui->pwgenPath->text());
+  QtPassSettings::setUsePwgen(ui->checkBoxUsePwgen->isChecked());
+  QtPassSettings::setAvoidCapitals(ui->checkBoxAvoidCapitals->isChecked());
+  QtPassSettings::setAvoidNumbers(ui->checkBoxAvoidNumbers->isChecked());
+  QtPassSettings::setLessRandom(ui->checkBoxLessRandom->isChecked());
+  QtPassSettings::setUseSymbols(ui->checkBoxUseSymbols->isChecked());
+  QtPassSettings::setPasswordConfiguration(getPasswordConfiguration());
+  QtPassSettings::setUseTemplate(ui->checkBoxUseTemplate->isChecked());
+  QtPassSettings::setPassTemplate(ui->plainTextEditTemplate->toPlainText());
+  QtPassSettings::setTemplateAllFields(
+      ui->checkBoxTemplateAllFields->isChecked());
+  QtPassSettings::setAutoPush(ui->checkBoxAutoPush->isChecked());
+  QtPassSettings::setAutoPull(ui->checkBoxAutoPull->isChecked());
+  QtPassSettings::setAlwaysOnTop(ui->checkBoxAlwaysOnTop->isChecked());
+
+  QtPassSettings::setVersion(VERSION);
+}
+
 /**
  * @brief ConfigDialog::on_radioButtonNative_clicked wrapper for
  * ConfigDialog::setGroupBoxState()
@@ -142,13 +178,9 @@ void ConfigDialog::on_radioButtonPass_clicked() { setGroupBoxState(); }
  * @brief ConfigDialog::setGroupBoxState update checkboxes.
  */
 void ConfigDialog::setGroupBoxState() {
-  if (ui->radioButtonPass->isChecked()) {
-    ui->groupBoxNative->setEnabled(false);
-    ui->groupBoxPass->setEnabled(true);
-  } else {
-    ui->groupBoxNative->setEnabled(true);
-    ui->groupBoxPass->setEnabled(false);
-  }
+  bool state = ui->radioButtonPass->isChecked();
+  ui->groupBoxNative->setEnabled(!state);
+  ui->groupBoxPass->setEnabled(state);
 }
 
 /**
@@ -162,7 +194,7 @@ QString ConfigDialog::selectExecutable() {
   if (dialog.exec())
     return dialog.selectedFiles().first();
   else
-    return "";
+    return QString();
 }
 
 /**
@@ -177,7 +209,7 @@ QString ConfigDialog::selectFolder() {
   if (dialog.exec())
     return dialog.selectedFiles().first();
   else
-    return "";
+    return QString();
 }
 
 /**
@@ -186,13 +218,14 @@ QString ConfigDialog::selectFolder() {
  */
 void ConfigDialog::on_toolButtonGit_clicked() {
   QString git = selectExecutable();
-  if (!git.isEmpty()) {
+  bool state = !git.isEmpty();
+  if (state) {
     ui->gitPath->setText(git);
-    ui->checkBoxUseGit->setEnabled(true);
   } else {
     useGit(false);
-    ui->checkBoxUseGit->setEnabled(false);
   }
+
+  ui->checkBoxUseGit->setEnabled(state);
 }
 
 /**
@@ -228,25 +261,18 @@ void ConfigDialog::on_toolButtonStore_clicked() {
  * @param index of selectbox (0 = no clipboard).
  */
 void ConfigDialog::on_comboBoxClipboard_activated(int index) {
-  if (index > 0) {
-    ui->checkBoxSelection->setEnabled(true);
-    ui->checkBoxAutoclear->setEnabled(true);
-    ui->checkBoxHidePassword->setEnabled(true);
-    ui->checkBoxHideContent->setEnabled(true);
-    if (ui->checkBoxAutoclear->isChecked()) {
-      ui->spinBoxAutoclearSeconds->setEnabled(true);
-      ui->labelSeconds->setEnabled(true);
-    } else {
-      ui->spinBoxAutoclearSeconds->setEnabled(false);
-      ui->labelSeconds->setEnabled(false);
-    }
+  bool state = index > 0;
+
+  ui->checkBoxSelection->setEnabled(state);
+  ui->checkBoxAutoclear->setEnabled(state);
+  ui->checkBoxHidePassword->setEnabled(state);
+  ui->checkBoxHideContent->setEnabled(state);
+  if (state) {
+    ui->spinBoxAutoclearSeconds->setEnabled(ui->checkBoxAutoclear->isChecked());
+    ui->labelSeconds->setEnabled(ui->checkBoxAutoclear->isChecked());
   } else {
-    ui->checkBoxSelection->setEnabled(false);
-    ui->checkBoxAutoclear->setEnabled(false);
     ui->spinBoxAutoclearSeconds->setEnabled(false);
     ui->labelSeconds->setEnabled(false);
-    ui->checkBoxHidePassword->setEnabled(false);
-    ui->checkBoxHideContent->setEnabled(false);
   }
 }
 
@@ -255,21 +281,9 @@ void ConfigDialog::on_comboBoxClipboard_activated(int index) {
  * options based on autoclear use.
  */
 void ConfigDialog::on_checkBoxAutoclearPanel_clicked() {
-  if (ui->checkBoxAutoclearPanel->isChecked()) {
-    ui->spinBoxAutoclearPanelSeconds->setEnabled(true);
-    ui->labelPanelSeconds->setEnabled(true);
-  } else {
-    ui->spinBoxAutoclearPanelSeconds->setEnabled(false);
-    ui->labelPanelSeconds->setEnabled(false);
-  }
-}
-
-/**
- * @brief ConfigDialog::useClipboard set the clipboard use from MainWindow.
- */
-void ConfigDialog::useClipboard(Enums::clipBoardType useClipboard) {
-  ui->comboBoxClipboard->setCurrentIndex(static_cast<int>(useClipboard));
-  on_comboBoxClipboard_activated(static_cast<int>(useClipboard));
+  bool state = ui->checkBoxAutoclearPanel->isChecked();
+  ui->spinBoxAutoclearPanelSeconds->setEnabled(state);
+  ui->labelPanelSeconds->setEnabled(state);
 }
 
 /**
@@ -292,15 +306,6 @@ void ConfigDialog::useAutoclear(bool useAutoclear) {
   on_checkBoxAutoclear_clicked();
 }
 
-/**
- * @brief ConfigDialog::setAutoclear set the clipboard autoclear timout from
- * MainWindow.
- * @param seconds
- */
-void ConfigDialog::setAutoclear(int seconds) {
-  ui->spinBoxAutoclearSeconds->setValue(seconds);
-}
-
 /**
  * @brief ConfigDialog::useAutoclearPanel set the panel autoclear use from
  * MainWindow.
@@ -311,30 +316,6 @@ void ConfigDialog::useAutoclearPanel(bool useAutoclearPanel) {
   on_checkBoxAutoclearPanel_clicked();
 }
 
-/**
- * @brief ConfigDialog::setAutoclearPanel set the panel autoclear timout from
- * MainWindow.
- * @param seconds
- */
-void ConfigDialog::setAutoclearPanel(int seconds) {
-  ui->spinBoxAutoclearPanelSeconds->setValue(seconds);
-}
-
-/**
- * @brief ConfigDialog::useClipboard set the use of clipboard from MainWindow.
- * @return
- */
-Enums::clipBoardType ConfigDialog::useClipboard() {
-  return static_cast<Enums::clipBoardType>(
-      ui->comboBoxClipboard->currentIndex());
-}
-
-/**
- * @brief ConfigDialog::useSelection return the clipboard type.
- * @return
- */
-bool ConfigDialog::useSelection() { return ui->checkBoxSelection->isChecked(); }
-
 /**
  * @brief ConfigDialog::on_checkBoxSelection_clicked checkbox clicked, update
  * state via ConfigDialog::on_comboBoxClipboard_activated
@@ -343,20 +324,6 @@ void ConfigDialog::on_checkBoxSelection_clicked() {
   on_comboBoxClipboard_activated(ui->comboBoxClipboard->currentIndex());
 }
 
-/**
- * @brief ConfigDialog::useAutoclear return the use of clipboard autoclear.
- * @return
- */
-bool ConfigDialog::useAutoclear() { return ui->checkBoxAutoclear->isChecked(); }
-
-/**
- * @brief ConfigDialog::getAutoclear return the clipboard autoclear timout.
- * @return
- */
-int ConfigDialog::getAutoclear() {
-  return ui->spinBoxAutoclearSeconds->value();
-}
-
 /**
  * @brief ConfigDialog::on_checkBoxAutoclear_clicked checkbox clicked, update
  * state via ConfigDialog::on_comboBoxClipboard_activated
@@ -365,74 +332,6 @@ void ConfigDialog::on_checkBoxAutoclear_clicked() {
   on_comboBoxClipboard_activated(ui->comboBoxClipboard->currentIndex());
 }
 
-/**
- * @brief ConfigDialog::useAutoclearPanel return panel autoclear usage.
- * @return
- */
-bool ConfigDialog::useAutoclearPanel() {
-  return ui->checkBoxAutoclearPanel->isChecked();
-}
-
-/**
- * @brief ConfigDialog::getAutoclearPanel return panel autoclear timeout.
- * @return
- */
-int ConfigDialog::getAutoclearPanel() {
-  return ui->spinBoxAutoclearPanelSeconds->value();
-}
-
-/**
- * @brief ConfigDialog::hidePassword return preference for hiding passwords from
- * shoulder-surfers.
- * @return
- */
-bool ConfigDialog::hidePassword() {
-  return ui->checkBoxHidePassword->isChecked();
-}
-
-/**
- * @brief ConfigDialog::hideContent return preference for hiding all information
- * from shoulder-surfers.
- * @return
- */
-bool ConfigDialog::hideContent() {
-  return ui->checkBoxHideContent->isChecked();
-}
-
-/**
- * @brief ConfigDialog::hidePassword set preference for hiding passwords from
- * shoulder-surfers.
- * @param hidePassword
- */
-void ConfigDialog::hidePassword(bool hidePassword) {
-  ui->checkBoxHidePassword->setChecked(hidePassword);
-}
-
-/**
- * @brief ConfigDialog::hideContent set preference for hiding all content from
- * shoulder-surfers.
- * @param hideContent
- */
-void ConfigDialog::hideContent(bool hideContent) {
-  ui->checkBoxHideContent->setChecked(hideContent);
-}
-
-/**
- * @brief ConfigDialog::addGPGId return preference for always adding gpg-id
- * changes to git.
- * @return
- */
-bool ConfigDialog::addGPGId() { return ui->checkBoxAddGPGId->isChecked(); }
-
-/**
- * @brief ConfigDialog::addGPGId set preference for always adding gpg-id changes
- * to git.
- * @param addGPGId
- */
-void ConfigDialog::addGPGId(bool addGPGId) {
-  ui->checkBoxAddGPGId->setChecked(addGPGId);
-}
-
 /**
  * @brief ConfigDialog::genKey tunnel function to make MainWindow generate a gpg
  * key pair.
@@ -582,7 +481,7 @@ void ConfigDialog::wizard() {
       SetFileAttributes(passStore.toStdWString().c_str(),
                         FILE_ATTRIBUTE_HIDDEN);
 #endif
-      if (useGit())
+      if (ui->checkBoxUseGit->isChecked())
         mainWindow->executePassGitInit();
       mainWindow->userDialog(passStore);
     }
@@ -613,15 +512,6 @@ void ConfigDialog::wizard() {
   }
 }
 
-/**
- * @brief ConfigDialog::useTrayIcon return preference for using a (system) tray
- * icon.
- * @return
- */
-bool ConfigDialog::useTrayIcon() {
-  return ui->checkBoxUseTrayIcon->isChecked();
-}
-
 /**
  * @brief ConfigDialog::hideOnClose return preference for hiding instead of
  * closing (quitting) application.
@@ -647,27 +537,14 @@ void ConfigDialog::useTrayIcon(bool useSystray) {
   }
 }
 
-/**
- * @brief ConfigDialog::hideOnClose set preference for hiding instead of closing
- * (quitting) application.
- * @param hideOnClose
- */
-void ConfigDialog::hideOnClose(bool hideOnClose) {
-  ui->checkBoxHideOnClose->setChecked(hideOnClose);
-}
-
 /**
  * @brief ConfigDialog::on_checkBoxUseTrayIcon_clicked enable and disable
  * related checkboxes.
  */
 void ConfigDialog::on_checkBoxUseTrayIcon_clicked() {
-  if (ui->checkBoxUseTrayIcon->isChecked()) {
-    ui->checkBoxHideOnClose->setEnabled(true);
-    ui->checkBoxStartMinimized->setEnabled(true);
-  } else {
-    ui->checkBoxStartMinimized->setEnabled(false);
-    ui->checkBoxHideOnClose->setEnabled(false);
-  }
+  bool state = ui->checkBoxUseTrayIcon->isChecked();
+  ui->checkBoxHideOnClose->setEnabled(state);
+  ui->checkBoxStartMinimized->setEnabled(state);
 }
 
 /**
@@ -689,10 +566,12 @@ void ConfigDialog::useGit(bool useGit) {
 }
 
 /**
- * @brief ConfigDialog::useGit retrun preference for using git.
- * @return
+ * @brief ConfigDialog::useOtp set preference for using otp plugin.
+ * @param useOtp
  */
-bool ConfigDialog::useGit() { return ui->checkBoxUseGit->isChecked(); }
+void ConfigDialog::useOtp(bool useOtp) {
+  ui->checkBoxUseOtp->setChecked(useOtp);
+}
 
 /**
  * @brief ConfigDialog::on_checkBoxUseGit_clicked enable or disable related
@@ -719,12 +598,6 @@ void ConfigDialog::on_toolButtonPwgen_clicked() {
   }
 }
 
-/**
- * @brief ConfigDialog::getPwgenPath return pwgen executable path.
- * @return
- */
-QString ConfigDialog::getPwgenPath() { return ui->pwgenPath->text(); }
-
 /**
  * @brief ConfigDialog::setPwgenPath set pwgen executable path.
  * Enable or disable related options in the interface.
@@ -768,132 +641,23 @@ void ConfigDialog::usePwgen(bool usePwgen) {
   on_checkBoxUsePwgen_clicked();
 }
 
-/**
- * @brief ConfigDialog::avoidCapitals set preference for avoiding uppercase
- * letters using pwgen.
- * @param avoidCapitals
- */
-void ConfigDialog::avoidCapitals(bool avoidCapitals) {
-  ui->checkBoxAvoidCapitals->setChecked(avoidCapitals);
+void ConfigDialog::setPasswordConfiguration(
+    const PasswordConfiguration &config) {
+  ui->spinBoxPasswordLength->setValue(config.length);
+  ui->passwordCharTemplateSelector->setCurrentIndex(config.selected);
+  if (config.selected != PasswordConfiguration::CUSTOM)
+    ui->lineEditPasswordChars->setEnabled(false);
+  ui->lineEditPasswordChars->setText(config.Characters[config.selected]);
 }
 
-/**
- * @brief ConfigDialog::avoidNumbers set preference for using numbers in pwgen
- * generated password.
- * @param avoidNumbers
- */
-void ConfigDialog::avoidNumbers(bool avoidNumbers) {
-  ui->checkBoxAvoidNumbers->setChecked(avoidNumbers);
-}
-
-/**
- * @brief ConfigDialog::lessRandom set preference for using less random
- * passwords.
- * @param lessRandom
- */
-void ConfigDialog::lessRandom(bool lessRandom) {
-  ui->checkBoxLessRandom->setChecked(lessRandom);
-}
-
-/**
- * @brief ConfigDialog::useSymbols set preference for using special characters
- * in pwgen.
- * @param useSymbols
- */
-void ConfigDialog::useSymbols(bool useSymbols) {
-  ui->checkBoxUseSymbols->setChecked(useSymbols);
-}
-
-/**
- * @brief ConfigDialog::setPasswordLength set the length of desired (generated)
- * passwords.
- * @param pwLen
- */
-void ConfigDialog::setPasswordLength(int pwLen) {
-  ui->spinBoxPasswordLength->setValue(pwLen);
-}
-
-/**
- * @brief ConfigDialog::setPasswordChars use these charcters to generate
- * password (non-pwgen option).
- * @param pwChars
- */
-void ConfigDialog::setPasswordChars(QString pwChars) {
-  ui->lineEditPasswordChars->setText(pwChars);
-}
-
-/**
- * @brief ConfigDialog::usePwgen return preference for using pwgen.
- * @return
- */
-bool ConfigDialog::usePwgen() { return ui->checkBoxUsePwgen->isChecked(); }
-
-/**
- * @brief ConfigDialog::avoidCapitals return preference for avoiding uppercase
- * letters using pwgen.
- * @return
- */
-bool ConfigDialog::avoidCapitals() {
-  return ui->checkBoxAvoidCapitals->isChecked();
-}
-
-/**
- * @brief ConfigDialog::avoidNumbers return preference for using numbers in
- * generated password using pwgen.
- * @return
- */
-bool ConfigDialog::avoidNumbers() {
-  return ui->checkBoxAvoidNumbers->isChecked();
-}
-
-/**
- * @brief ConfigDialog::lessRandom return preference for using less random
- * passwords in pwgen.
- * @return
- */
-bool ConfigDialog::lessRandom() { return ui->checkBoxLessRandom->isChecked(); }
-
-/**
- * @brief ConfigDialog::useSymbols return preference for using special
- * characters with pwgen.
- * @return
- */
-bool ConfigDialog::useSymbols() { return ui->checkBoxUseSymbols->isChecked(); }
-
-/**
- * @brief ConfigDialog::getPasswordLength return desired length for generated
- * passwords.
- * @return
- */
-int ConfigDialog::getPasswordLength() {
-  return ui->spinBoxPasswordLength->value();
-}
-
-/**
- * @brief ConfigDialog::getPasswordChars return characters to use in password
- * generation (non-pwgen).
- * @return
- */
-QString ConfigDialog::getPasswordChars() {
-  return ui->lineEditPasswordChars->text();
-}
-
-/**
- * @brief ConfigDialog::setPwdTemplateSelector sets the current index of the
- * password characters template combobox
- * @return
- */
-void ConfigDialog::setPwdTemplateSelector(int selection) {
-  ui->passwordCharTemplateSelector->setCurrentIndex(selection);
-}
-
-/**
- * @brief ConfigDialog::getPwdTemplateSelector returns the selection of the
- * password characters template combobox
- * @return
- */
-int ConfigDialog::getPwdTemplateSelector() {
-  return ui->passwordCharTemplateSelector->currentIndex();
+PasswordConfiguration ConfigDialog::getPasswordConfiguration() {
+  PasswordConfiguration config;
+  config.length = ui->spinBoxPasswordLength->value();
+  config.selected = static_cast<PasswordConfiguration::characterSet>(
+      ui->passwordCharTemplateSelector->currentIndex());
+  config.Characters[PasswordConfiguration::CUSTOM] =
+      ui->lineEditPasswordChars->text();
+  return config;
 }
 
 /**
@@ -903,7 +667,8 @@ int ConfigDialog::getPwdTemplateSelector() {
  * @param entry of
  */
 void ConfigDialog::on_passwordCharTemplateSelector_activated(int index) {
-  ui->lineEditPasswordChars->setText(mainWindow->pwdConfig.Characters[index]);
+  ui->lineEditPasswordChars->setText(
+      QtPassSettings::getPasswordConfiguration().Characters[index]);
   if (index == 3) {
     ui->lineEditPasswordChars->setEnabled(true);
   } else {
@@ -911,34 +676,6 @@ void ConfigDialog::on_passwordCharTemplateSelector_activated(int index) {
   }
 }
 
-/**
- * @brief ConfigDialog::setLineEditEnabled enabling/disabling the textbox with
- * the
- * password characters
- * @param b enable/disable
- */
-void ConfigDialog::setLineEditEnabled(bool b) {
-  ui->lineEditPasswordChars->setEnabled(b);
-}
-
-/**
- * @brief ConfigDialog::startMinimized return preference for starting
- * application minimized (tray icon).
- * @return
- */
-bool ConfigDialog::startMinimized() {
-  return ui->checkBoxStartMinimized->isChecked();
-}
-
-/**
- * @brief ConfigDialog::startMinimized set preference for starting application
- * minimized (tray icon).
- * @param startMinimized
- */
-void ConfigDialog::startMinimized(bool startMinimized) {
-  ui->checkBoxStartMinimized->setChecked(startMinimized);
-}
-
 /**
  * @brief ConfigDialog::on_checkBoxUseTemplate_clicked enable or disable the
  * template field and options.
@@ -957,94 +694,3 @@ void ConfigDialog::useTemplate(bool useTemplate) {
   ui->checkBoxUseTemplate->setChecked(useTemplate);
   on_checkBoxUseTemplate_clicked();
 }
-
-/**
- * @brief ConfigDialog::useTemplate return preference for using templates.
- * @return
- */
-bool ConfigDialog::useTemplate() {
-  return ui->checkBoxUseTemplate->isChecked();
-}
-
-/**
- * @brief ConfigDialog::setTemplate set the desired template.
- * @param passTemplate
- */
-void ConfigDialog::setTemplate(QString passTemplate) {
-  ui->plainTextEditTemplate->setPlainText(passTemplate);
-}
-
-/**
- * @brief ConfigDialog::getTemplate return the desired template.
- * @return
- */
-QString ConfigDialog::getTemplate() {
-  return ui->plainTextEditTemplate->toPlainText();
-}
-
-/**
- * @brief ConfigDialog::autoPull set preference for automatically pulling from
- * git
- * @param autoPull
- */
-void ConfigDialog::autoPull(bool autoPull) {
-  ui->checkBoxAutoPull->setChecked(autoPull);
-}
-
-/**
- * @brief ConfigDialog::autoPush set preference for automatically pushing to git
- * @param autoPush
- */
-void ConfigDialog::autoPush(bool autoPush) {
-  ui->checkBoxAutoPush->setChecked(autoPush);
-}
-
-/**
- * @brief ConfigDialog::autoPull return preference for automatically pulling
- * from git
- * @return
- */
-bool ConfigDialog::autoPull() { return ui->checkBoxAutoPull->isChecked(); }
-
-/**
- * @brief ConfigDialog::autoPush return preference for automatically pushing to
- * git
- * @return
- */
-bool ConfigDialog::autoPush() { return ui->checkBoxAutoPush->isChecked(); }
-
-/**
- * @brief ConfigDialog::templateAllFields return preference for templating all
- * tokenisable fields
- * @return
- */
-bool ConfigDialog::templateAllFields() {
-  return ui->checkBoxTemplateAllFields->isChecked();
-}
-
-/**
- * @brief ConfigDialog::templateAllFields set preference for templating all
- * tokenisable fields
- * @param templateAll
- */
-void ConfigDialog::templateAllFields(bool templateAll) {
-  ui->checkBoxTemplateAllFields->setChecked(templateAll);
-}
-
-/**
- * @brief ConfigDialog::alwaysOnTop set preference for running application on
- * top of others
- * @param alwaysOnTop
- */
-void ConfigDialog::alwaysOnTop(bool alwaysOnTop) {
-  ui->checkBoxAlwaysOnTop->setChecked(alwaysOnTop);
-}
-
-/**
- * @brief ConfigDialog::alwaysOnTop return preference for running application on
- * top of others.
- * @return
- */
-bool ConfigDialog::alwaysOnTop() {
-  return ui->checkBoxAlwaysOnTop->isChecked();
-}
