@@ -1,10 +1,6 @@
 #ifndef TRAYICON_H_
 #define TRAYICON_H_
 
-#include <QAction>
-#include <QApplication>
-#include <QMainWindow>
-#include <QMenu>
 #include <QSystemTrayIcon>
 #include <QWidget>
 
@@ -12,6 +8,9 @@
     \class TrayIcon
     \brief Handles the systemtray icon and menu.
  */
+class QAction;
+class QMainWindow;
+class QMenu;
 class TrayIcon : public QWidget {
   Q_OBJECT
 
@@ -19,6 +18,7 @@ public:
   explicit TrayIcon(QMainWindow *parent);
   void showMessage(QString title, QString msg, int time);
   void setVisible(bool visible);
+  bool getIsAllocated();
 
 signals:
 
@@ -40,6 +40,8 @@ private:
   QSystemTrayIcon *sysTrayIcon;
   QMenu *trayIconMenu;
   QMainWindow *parentwin;
+
+  bool isAllocated;
 };
 
 #endif // TRAYICON_H_
