@@ -1,17 +1,16 @@
 #ifndef USERSDIALOG_H_
 #define USERSDIALOG_H_
 
-#include "datahelpers.h"
-#include <QCloseEvent>
-#include <QDateTime>
+#include "userinfo.h"
+
 #include <QDialog>
 #include <QList>
-#include <QStandardItemModel>
 
 namespace Ui {
 class UsersDialog;
 }
 
+class QCloseEvent;
 class QListWidgetItem;
 
 /*!
